@@ -382,7 +382,8 @@ class EndpointRouter(Router):
         ''' Set up the initial roster of nodes using the provided discovery endpoints. '''
         try:
             self._bootstrap()
-        except DaxValidationError:
+        except DaxValidationError as e:
+            logger.info("Could not start bootstrap due to DaxValidationError: %s", e)
             raise
         if not self._service_endpoints:
             raise DaxClientError('Failed to configure cluster endpoints from {}'.format(self._discovery_endpoints), DaxErrorCode.NoRoute)
@@ -416,10 +417,11 @@ class EndpointRouter(Router):
             seeds_from_endpoint = _resolve_dns(host, port)
             logger.debug('Resolved addresses %s for %s', seeds_from_endpoint, host)
             seeds += seeds_from_endpoint
+            endpoint_scheme = scheme # should be the same for all endpoints
 
         random.shuffle(seeds)
         logger.debug('seeds: %s', seeds)
-        service_endpoints = self._get_endpoints_from_seeds(scheme, seeds)
+        service_endpoints = self._get_endpoints_from_seeds(endpoint_scheme, seeds)
         logger.debug('service_endpoints: %s', service_endpoints)
 
         if service_endpoints:
@@ -431,7 +433,7 @@ class EndpointRouter(Router):
             # Stop after the first successful call
             try:
                 client = self._client_factory(hostname, sockaddr)
-            except Exception as e: # pylint: disable=broad-except
+            except Exception: # pylint: disable=broad-except
                 logger.info('Could not connect to %s://%s:%s', scheme, ip,
                             port, exc_info=True)
                 continue
@@ -455,7 +457,7 @@ class EndpointRouter(Router):
                         raise
                 except DaxValidationError:
                     raise
-                except Exception as e: # pylint: disable=broad-except
+                except Exception: # pylint: disable=broad-except
                     logger.info('Failed to retrieve endpoints from %s://%s:%s',
                                 scheme, ip, port, exc_info=True)
                     continue
@@ -588,8 +590,8 @@ class EndpointBackend(object):
             if not self.client:
                 try:
                     self.client = self._client_factory(self._service_endpoint.hostname, self.addrport)
-                except Exception as e:
-                    logger.warning('Health check failed to get client', e)
+                except Exception as e: # pylint: disable=broad-except
+                    logger.warning("Health check failed to get client with Error %s", e)
 
             # Determine health by calling endpoints
             try:
